pub struct BuffTemplate {
pub id: BuffTemplateId,
pub title: I18nString,
pub description: I18nString,
pub icon_path: String,
pub effect: BuffEffect,
}Fields
id: BuffTemplateIdtitle: I18nStringdescription: I18nStringicon_path: Stringeffect: BuffEffectTrait Implementations
Sourceimpl Clone for BuffTemplate
impl Clone for BuffTemplate
Sourcefn clone(&self) -> BuffTemplate
fn clone(&self) -> BuffTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuffTemplate
impl Debug for BuffTemplate
Sourceimpl<'de> Deserialize<'de> for BuffTemplate
impl<'de> Deserialize<'de> for BuffTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuffTemplate
impl JsonSchema for BuffTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for BuffTemplate
impl Serialize for BuffTemplate
Sourceimpl Tsify for BuffTemplate
impl Tsify for BuffTemplate
const DECL: &'static str = "export interface BuffTemplate {\n id: BuffTemplateId;\n title: I18nString;\n description: I18nString;\n icon_path: string;\n effect: BuffEffect;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>